# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.core.utils.functions import import_class

from image_cropping import ImageCroppingMixin

from isolmant.product.cms import models as cms_settings


class FilterPlugin(CMSPluginBase):
    model = cms_settings.FilterSettings
    name = _("Filter")
    module = _("Isolmant")
    render_template = "product/cms_plugins/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status:
            request = context['request']
            self.render_template = instance.template
            if instance.model_class:
                model_class = import_class(instance.model_class)
                object_name = model_class._meta.model_name
                if hasattr(model_class, 'get_cms_qs'):
                    object_list = model_class.get_cms_qs()
                else:
                    object_list = model_class.objects.filter(status=1)
            else:
                object_list = []
                object_name = ''
            active_filter = request.GET.get('filter', '')
            context.update({
                'object': instance,
                'object_name': object_name,
                'object_list': object_list,
                'placeholder': placeholder,
                'active_filter': active_filter
            })
        return context

plugin_pool.register_plugin(FilterPlugin)


class ListPlugin(CMSPluginBase):
    model = cms_settings.ListSettings
    name = _("List")
    module = _("Isolmant")
    render_template = "product/cms_plugins/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status:
            self.render_template = instance.template
            model_class = import_class(instance.model_class)
            if hasattr(instance, 'language'):
                if hasattr(model_class, 'get_cms_qs_{}'.format(instance.language)):
                    object_list = getattr(model_class, 'get_cms_qs_{}'.format(instance.language))()
                else:
                    if hasattr(model_class, 'get_cms_qs'):
                        object_list = model_class.get_cms_qs()
                    else:
                        object_list = model_class.objects.filter(status=1)
                    try:
                        object_list = object_list.filter(language=instance.language)
                    except Exception:
                        pass
            else:
                if hasattr(model_class, 'get_cms_qs'):
                    object_list = model_class.get_cms_qs()
                else:
                    object_list = model_class.objects.filter(status=1)

            context.update({
                'object': instance,
                'object_name': model_class._meta.model_name,
                'object_list': object_list,
                'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(ListPlugin)


class MenuButtonPlugin(CMSPluginBase):
    model = cms_settings.MenuButtonSettings
    name = _("Menu Button")
    module = _("Isolmant")
    render_template = 'product/cms_plugins/squared_menu_button.html'

    def render(self, context, instance, placeholder):
        if instance.status:
            self.render_template = instance.template
            context.update({
                'object': instance,
                'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(MenuButtonPlugin)


class GalleryPlugin(CMSPluginBase):
    model = cms_settings.GallerySettings
    name = _("Gallery")
    module = _("Isolmant")
    render_template = 'product/cms_plugins/gallery.html'

    def render(self, context, instance, placeholder):
        if instance.status:
            context.update({
                'object': instance,
                'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(GalleryPlugin)


class LinkAdmin(admin.ModelAdmin):
    pass

admin.site.register(cms_settings.LinkItem, LinkAdmin)


class SliderItemInlineAdmin(ImageCroppingMixin, admin.StackedInline):
    model = cms_settings.SliderItem
    prepopulated_fields = {"slug": ("title",)}


class SliderPlugin(ImageCroppingMixin, CMSPluginBase):
    model = cms_settings.SliderSettings
    name = _("Slider")
    module = _("Isolmant")
    inlines = (SliderItemInlineAdmin,)
    render_template = 'product/cms_plugins/slider.html'

    def render(self, context, instance, placeholder):
        slider_items = instance.slider_items.all()
        if instance.status:
            context.update({
                'object': instance,
                'placeholder': placeholder,
                "slides": slider_items
            })
        return context

plugin_pool.register_plugin(SliderPlugin)


class MetaTagPlugin(CMSPluginBase):
    model = cms_settings.MetaTagSettings
    name = _("Meta Tag")
    module = _("Isolmant")
    render_template = 'product/cms_plugins/meta_tag.html'

    def render(self, context, instance, placeholder):
        if instance.status:
            context.update({
                'object': instance,
                'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(MetaTagPlugin)
