# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Product",
            'display': "tabs",
            'children': [Models(), OtherModels(), MediaModels()]
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class ProductDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Product",
            'display': "tabs",
            'children': [Models(), OtherModels(), MediaModels(), ShowcaseModels()]
        })
        super(ProductDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Product"),
            'models': (
                'isolmant.product.models.Product',
                'isolmant.product.models.ProductLabel',
            ),
        })
        super(Models, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Others"),
            'models': (
                'isolmant.product.models.Category',
                'isolmant.product.models.SubCategory',
                'isolmant.product.models.Application',
                'isolmant.product.models.Solution',
                'isolmant.product.models.Reference',
                'isolmant.product.models.ReferenceCategory',
                'isolmant.product.models.AdvancedFilter',
            ),
        })
        super(OtherModels, self).__init__(**kwargs)


class MediaModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Media"),
            'models': (
                'isolmant.product.models.Media',
                'isolmant.product.models.Gallery',
                'isolmant.product.models.GalleryImage'
            ),
        })
        super(MediaModels, self).__init__(**kwargs)


class ShowcaseModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Showcase"),
            'models': (
                'isolmant.product.models.Press',
                'isolmant.product.models.News',
                'isolmant.product.models.Blog',
                'isolmant.product.models.Highlight',
                'isolmant.product.models.HomePresentation',
                'isolmant.product.models.Convention',
                'isolmant.product.models.Course'
            ),
        })
        super(ShowcaseModels, self).__init__(**kwargs)


class ShowcaseDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Showcase",
            'display': "tabs",
            'children': [ShowcaseModels()]
        })
        super(ShowcaseDashboard, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin
jmb_dashboard.register_group(ProductDashboard, 'isolmant.product')
# Used in /admin/Product
admin_tools.dashboard.register(DefaultAppDashboard, 'isolmant.product')
jmb_dashboard.unregister_group('jmb.showcase')
jmb_dashboard.register_group(ShowcaseDashboard, 'jmb.showcase')
